
const Cart = require('../model/Cart');


exports.addToCart = async (req, res) => {
  const { userId } = req.body;
  const { productId, quantity } = req.body;

  try {
    let cart = await Cart.findOne({ userId }).populate('items.product');

    if (!cart) {
      cart = new Cart({
        userId,
        items: [{ product: productId, quantity }],
      });
    } else {
      const existingItem = cart.items.find(item => item.product._id.toString() === productId);

      if (existingItem) {
        existingItem.quantity += quantity;
      } else {
        cart.items.push({ product: productId, quantity });
      }
    }

    await cart.save();

    console.log(`Product with ID ${productId} added to cart for user with ID ${userId}`);

    res.json({ message: 'Item added to cart successfully' });
  } catch (error) {
    console.error(error);
    res.status(500).json({ error: 'Internal Server Error' });
  }
};

exports.updateCart = async (req, res) => {
  const { userId, product, quantity } = req.body;

  try {
    let cart = await Cart.findOne({ userId });

    if (!cart) {
      return res.status(404).json({ error: 'Cart not found for the user' });
    }

    const existingItem = cart.items.find(item => item.product.toString() === product);

    if (!existingItem) {
      return res.status(404).json({ error: 'Product not found in the cart' });
    }

    existingItem.quantity = quantity;

    await cart.save();

    res.json({ message: 'Quantity updated successfully' });
  } catch (error) {
    console.error(error);
    res.status(500).json({ error: 'Internal Server Error' });
  }
};

exports.removeFromCart = async (req, res) => {
  const { userId, productId } = req.body;

  try {
    let cart = await Cart.findOne({ userId });

    if (!cart) {
      return res.status(404).json({ error: 'Cart not found for the user' });
    }

    // Remove the product from the cart
    cart.items = cart.items.filter(item => item.productId.toString() !== productId);

    await cart.save();

    res.json({ message: 'Product removed from cart successfully' });
  } catch (error) {
    console.error(error);
    res.status(500).json({ error: 'Internal Server Error' });
  }
};

// Assuming you have middleware that adds user information to the request object
exports.getCartDetails = async (req, res) => {
  const { userId } = req.params;
  try {
    const cart = await Cart.findOne({ userId });
    if (!cart) {
      return res.status(404).json({ message: 'Cart not found for the user' });
    }

    return res.json({ items: cart.items });
  } catch (error) {
    console.error('Error fetching cart details:', error);
    res.status(500).json({ error: 'Internal Server Error' });
  }
};