const mongoose = require('mongoose');

const cartItemSchema = new mongoose.Schema({
  product: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Product',
    required: false,
  },
  quantity: {
    type: Number,
    default: 1,
  },
});

const cartSchema = new mongoose.Schema({
  userId: { type: String }, // For authenticated users
  anonymousUserId: { type: String }, // For anonymous users
  items: [
    {
      product: { type: mongoose.Schema.Types.ObjectId, ref: 'Product' },
      quantity: { type: Number, default: 1 },
    },
  ],
});


// Method to find a cart by user ID
cartSchema.statics.findByUserId = function (userId) {
  return this.findOne({ userId });
};

// Method to find a cart by anonymous user ID
cartSchema.statics.findByAnonymousUserId = function (anonymousUserId) {
  return this.findOne({ anonymousUserId });
};

const Cart = mongoose.model('Cart', cartSchema);

module.exports = Cart;

