const express = require('express');
const router = express.Router();
const cartController = require('../controllers/cart');
const auth = require("../auth");

const { authenticateToken, extractAnonymousUserId } = auth;

// Route to add an item to the cart
router.post('/add-to-cart', extractAnonymousUserId, cartController.addToCart);

// Update cart route
router.put('/update-cart', extractAnonymousUserId, cartController.updateCart);

router.delete('/remove-from-cart', extractAnonymousUserId, cartController.removeFromCart);

// Route to get cart details for a specific user
router.get('/user/:userId', cartController.getCartDetails);

// Route to get cart details for an anonymous user
router.get('/anonymous/:anonymousUserId', cartController.getCartDetailsForAnonymousUser);

router.post('/clear-cart', authenticateToken, cartController.clearCart);

module.exports = router;
