const express = require("express")
const router = express.Router()
const userController = require("../controllers/user")

const auth = require("../auth");

const { authenticateToken, verifyAdmin, verifyUser } = auth;

router.post("/apply-promo-code", authenticateToken, userController.applyPromoCode)

router.get("/details", authenticateToken, userController.userDetails)

// User registration route
router.post("/register", userController.registerUser)

router.post("/check-email", userController.checkEmail)

router.post("/reset-password", userController.resetPassword)

// User authentication route
router.post("/authenticate", userController.authenticateUser)

// Update user data route
router.put("/update", authenticateToken, userController.updateUserData)

// Retrieve user details
router.get('/retrieveUser', authenticateToken, verifyUser, userController.getUserDetails);

// EXCLUSIVE ADMIN ACCOUNT
// Set user to Admin User
router.post('/set-admin', authenticateToken, verifyAdmin, userController.setAdmin);

router.post('/create-promo-code', authenticateToken, verifyAdmin, userController.createPromoCode);
router.delete('/delete-promo-code/:id', authenticateToken, verifyAdmin, userController.deletePromoCode);
router.get('/promo-code', authenticateToken, verifyAdmin, userController.showPromoCodes);

// Address
router.post('/get-address', authenticateToken, verifyUser, userController.getAddresses);

router.post('/create-address', authenticateToken, verifyUser, userController.createAddress);

router.delete('/delete-address/:id', authenticateToken, userController.deleteAddress);

router.put('/update-address/:id', authenticateToken, userController.updateAddress);

module.exports = router
