import React, { useState, useEffect } from "react";
import { Modal, Button, Form } from "react-bootstrap";

const EditAddress = ({ show, onHide, onSave, address }) => {
    const [editedAddress, setEditedAddress] = useState({ ...address });
    const [updateStatus, setUpdateStatus] = useState(null);

  useEffect(() => {
    setEditedAddress({ ...address });
  }, [address]);

  const handleChange = (e) => {
    const { name, value } = e.target;
    console.log(`Updating ${name} to:`, value);
    setEditedAddress((prevAddress) => ({
      ...prevAddress,
      [name]: value,
    }));
  };

  const handleSave = async () => {
    console.log("Saving edited address:", editedAddress);
    try {
      const response = await onSave(editedAddress);
      if (response.ok) {
        console.log("Address updated successfully:", editedAddress._id);
        setUpdateStatus("success");
      } else {
        console.error("Failed to update address:", response.status);
        setUpdateStatus("error");
      }
    } catch (error) {
      console.error("Error updating address:", error);
      setUpdateStatus("error");
    }
  };
  return (
    <Modal show={show} onHide={onHide}>
      <Modal.Header closeButton>
        <Modal.Title>Edit Address</Modal.Title>
      </Modal.Header>
      <Modal.Body>
        <Form>
          <Form.Group controlId="street">
            <Form.Label>Street</Form.Label>
            <Form.Control
              type="text"
              name="street"
              value={editedAddress.street}
              onChange={handleChange}
            />
          </Form.Group>
          <Form.Group controlId="zipCode">
            <Form.Label>Zip Code</Form.Label>
            <Form.Control
              type="text"
              name="zipCode"
              value={editedAddress.zipCode}
              onChange={handleChange}
            />
          </Form.Group>
          <Form.Group controlId="city">
            <Form.Label>City</Form.Label>
            <Form.Control
              type="text"
              name="city"
              value={editedAddress.city}
              onChange={handleChange}
            />
          </Form.Group>
          <Form.Group controlId="state">
            <Form.Label>State</Form.Label>
            <Form.Control
              type="text"
              name="state"
              value={editedAddress.state}
              onChange={handleChange}
            />
          </Form.Group>
          <Form.Group controlId="country">
            <Form.Label>Country</Form.Label>
            <Form.Control
              type="text"
              name="country"
              value={editedAddress.country}
              onChange={handleChange}
            />
          </Form.Group>
        </Form>
      </Modal.Body>
      <Modal.Footer>
        <Button variant="secondary" onClick={onHide}>
          Close
        </Button>
        <Button variant="primary" onClick={handleSave}>
          Save Changes
        </Button>
      </Modal.Footer>
    </Modal>
  );
};

export default EditAddress;
