import React, { useContext } from 'react';
import { Container, Row, Col, Form, Button } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import UserContext from '../UserContext';

const Footer = () => {
  const { user } = useContext(UserContext);

  return (
    <footer className="bg-dark text-white py-4">
      <Container>
        <Row>
          {/* Store Information */}
          <Col md={3}>
            <h3 className="mb-4">STORE INFORMATION</h3>
            <p className='text-white'><i className="bi bi-chevron-right"></i> 999F IGOP Building</p>
            <p className='text-white'><i className="bi bi-chevron-right"></i> +639-123-456-7890</p>
            <p className='text-white'><i className="bi bi-chevron-right"></i> customercare@istore.com.ph</p>
          </Col>

          {/* Our Company */}
          <Col md={3}>
            <h3 className="mb-4">OUR COMPANY</h3>
            <ul className="list-unstyled">
              <li className='pb-2'><a href="#" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> Terms and conditions of use</a></li>
              <li className='pb-2'><a href="#" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> About us</a></li>
              <li className='pb-2'><a href="#" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> Contact us</a></li>
              <li className='pb-2'><a href="#" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> Stores</a></li>
            </ul>
          </Col>

          {/* Your Account */}
          <Col md={3}>
            <h3 className="mb-4">YOUR ACCOUNT</h3>
            <ul className="list-unstyled">
              <li><a href="#" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> Orders</a></li>
              <li>
              {user && user.id !== null ? (
                  <a href="/profile" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> Profile</a>
                ) : (
                  <a href="/login" className="text-decoration-none text-white"><i className="bi bi-chevron-right"></i> Login</a>
                )}
              </li>
            </ul>
          </Col>

          {/* Newsletter */}
          <Col md={3}>
            <h3 className="mb-4">NEWSLETTER</h3>
            <Form>
              <Form.Group controlId="emailForm" className="mb-2">
                <Form.Control type="email" placeholder="Enter your email" />
              </Form.Group>
              <Button variant="light" type="submit" className="d-flex align-items-center">
                <i className="bi bi-chevron-right me-2"></i>Subscribe
              </Button>
              <p className="mt-2 text-white">Sign up and get the latest deals, offers & updates from our store. You may unsubscribe at any moment. For that purpose, please find our contact info in the legal notice.</p>
            </Form>
          </Col>
        </Row>

        {/* Social Media Icons */}
        <Row className="mt-4 text-center">
          <Col>
            <h3>CONNECT WITH US</h3>
            <p className="mb-0">
              <a href="#" className="text-white me-3"><i className="bi bi-facebook"></i></a>
              <a href="#" className="text-white me-3"><i className="bi bi-twitter"></i></a>
              <a href="#" className="text-white"><i className="bi bi-instagram"></i></a>
            </p>
          </Col>
        </Row>
      </Container>
    </footer>
  );
};

export default Footer;
